/*
  ***************************************************************************
  File:    S_APIDAT.H
  Project: API Library
  Purpose: Defines all data structures used locally by the API layer. 
  Company: Comtrol Corporation
  Author:  Jerry Medin
  ***************************************************************************
  Copyright 1993 Comtrol Corporation. All rights reserved.
  Subject to developers license agreement.
  ***************************************************************************
*/
#if WINDAPI
#include <windows.h>
#endif

#include "s_types.h"
#include "c_8530.h"
#include "sc_ip.h"
#include "sc_ipdef.h"

/*
******************************************************************************
  Define simple arrays that aid in the error checking for the API 
  Library function parameters.
******************************************************************************
*/
#define MAXDEV 127 
#define MAXNUMOTS 3
#define MAXNUMBAUDS 19
#define MAXNUMPARITYS 3
#define MAXNUMDATABS 4
#define MAXNUMSTOPBS 3

static unsigned int far aaOpenTypeCheck[MAXNUMOTS]={COM_TX, COM_RX, COM_TX | COM_RX}; 

static unsigned char far aaBaudRateCheck[MAXNUMBAUDS]={COM_BAUD_50, COM_BAUD_75, COM_BAUD_110,
                                      COM_BAUD_134,COM_BAUD_150,COM_BAUD_300,
                                      COM_BAUD_600,COM_BAUD_1200,COM_BAUD_1800,
                                      COM_BAUD_2000,COM_BAUD_2400,COM_BAUD_3600,
                                      COM_BAUD_4800,COM_BAUD_7200,COM_BAUD_9600,
                                      COM_BAUD_19200,COM_BAUD_38400,COM_BAUD_56000,
                                      COM_BAUD_76800};

static unsigned char far aaParityCheck[MAXNUMPARITYS]={COM_PAR_NONE,COM_PAR_EVEN,COM_PAR_ODD}; 

static unsigned char far aaDataBCheck[MAXNUMDATABS]={COM_DATABIT_5,COM_DATABIT_6,COM_DATABIT_7,
                                    COM_DATABIT_8}; 

static unsigned char far aaStopBCheck[MAXNUMSTOPBS]={0x04,0x08,0x0c}; 


#define FLOWCHECK  COM_FLOW_NONE | COM_FLOW_IS | COM_FLOW_IH | \
                   COM_FLOW_OS | COM_FLOW_OH | COM_FLOW_OXANY 


#define DETECTCHECK  COM_DEN_PARITY | COM_DEN_RXOVR | COM_DEN_FRAME | \
                     COM_DEN_CD | COM_DEN_CTS | COM_DEN_SYNCHUNT | \
                     COM_DEN_TXUNDRUN | COM_DEN_BKABORT | COM_DEN_DSR | \
                     COM_DEN_RI | COM_DEN_BUFOVR

#define MDMCTLCHECK  COM_MDM_DTR | COM_MDM_RTS 


/*
******************************************************************************
  Define an API queue to hold messages when the Windows message queue 
  fills up and PostMessage fails.
******************************************************************************
*/
#if WINDAPI
POSTQ_T far aaPostQ;
#endif



/*
******************************************************************************
  Define a data structure that holds pointers to important data areas in
  the SSCI library.
******************************************************************************
*/

CRITPTR_T far aaCritPtrs;


/*
******************************************************************************
  Define a data structure that holds a window handle for each open device.
******************************************************************************
*/

unsigned int far aaLineOpenTable [128];/* flag or window handle for each device */


/*
******************************************************************************
  Define a data structure for the number of lines for each controller.
******************************************************************************
*/

int far aaNumLines[NUM_CTLRS];


/*
******************************************************************************
  Define the event function pointers.
******************************************************************************
*/
#if !WINDAPI
void (*aaBreakEventP)(int);
void (*aaMdmChgEventP)(int,UBYTE_T,UBYTE_T);
void (*aaRxErrorEventP)(int,UBYTE_T);
void (*aaRxEventP)(int);
#endif


